==> webpdf-wsclient-2.0.3-sources.jar: net/webpdf/wsclient/schema/extraction/text/TextsType.java <==

package net.webpdf.wsclient.schema.extraction.text;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for texts element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="texts"&gt;
 *   &lt;complexType&gt;
 *     &lt;complexContent&gt;
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *         &lt;sequence&gt;
 *           &lt;element name="text" type="{http://schema.webpdf.de/1.0/extraction/text}TextType" maxOccurs="unbounded" minOccurs="0"/&gt;
 *           &lt;element name="link" type="{http://schema.webpdf.de/1.0/extraction/text}LinkType" maxOccurs="unbounded" minOccurs="0"/&gt;
 *           &lt;element name="paragraph" type="{http://schema.webpdf.de/1.0/extraction/text}ParagraphType" maxOccurs="unbounded" minOccurs="0"/&gt;
 *           &lt;element name="word" type="{http://schema.webpdf.de/1.0/extraction/text}WordType" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;/sequence&gt;
 *       &lt;/restriction&gt;
 *     &lt;/complexContent&gt;
 *   &lt;/complexType&gt;
 * &lt;/element&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "text",
    "link",
    "paragraph",
    "word"
})
@XmlRootElement(name = "texts")
public class TextsType {

    protected List<TextType> text;
    protected List<LinkType> link;
    protected List<ParagraphType> paragraph;
    protected List<WordType> word;

    /**
     * Gets the value of the text property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the text property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getText().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TextType }
     * 
     * 
     */
    public List<TextType> getText() {
        if (text == null) {
            text = new ArrayList<TextType>();
        }
        return this.text;
    }

    public boolean isSetText() {
        return ((this.text!= null)&&(!this.text.isEmpty()));
    }

    public void unsetText() {
        this.text = null;
    }

    /**
     * Gets the value of the link property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the link property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getLink().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link LinkType }
     * 
     * 
     */
    public List<LinkType> getLink() {
        if (link == null) {
            link = new ArrayList<LinkType>();
        }
        return this.link;
    }

    public boolean isSetLink() {
        return ((this.link!= null)&&(!this.link.isEmpty()));
    }

    public void unsetLink() {
        this.link = null;
    }

    /**
     * Gets the value of the paragraph property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the paragraph property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getParagraph().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ParagraphType }
     * 
     * 
     */
    public List<ParagraphType> getParagraph() {
        if (paragraph == null) {
            paragraph = new ArrayList<ParagraphType>();
        }
        return this.paragraph;
    }

    public boolean isSetParagraph() {
        return ((this.paragraph!= null)&&(!this.paragraph.isEmpty()));
    }

    public void unsetParagraph() {
        this.paragraph = null;
    }

    /**
     * Gets the value of the word property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the word property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getWord().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link WordType }
     * 
     * 
     */
    public List<WordType> getWord() {
        if (word == null) {
            word = new ArrayList<WordType>();
        }
        return this.word;
    }

    public boolean isSetWord() {
        return ((this.word!= null)&&(!this.word.isEmpty()));
    }

    public void unsetWord() {
        this.word = null;
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/extraction/text/TextsType.java <==

package net.webpdf.wsclient.schema.extraction.text;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for texts element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <element name="texts">
 *   <complexType>
 *     <complexContent>
 *       <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         <sequence>
 *           <element name="text" type="{http://schema.webpdf.de/1.0/extraction/text}TextType" maxOccurs="unbounded" minOccurs="0"/>
 *           <element name="link" type="{http://schema.webpdf.de/1.0/extraction/text}LinkType" maxOccurs="unbounded" minOccurs="0"/>
 *           <element name="paragraph" type="{http://schema.webpdf.de/1.0/extraction/text}ParagraphType" maxOccurs="unbounded" minOccurs="0"/>
 *           <element name="word" type="{http://schema.webpdf.de/1.0/extraction/text}WordType" maxOccurs="unbounded" minOccurs="0"/>
 *         </sequence>
 *       </restriction>
 *     </complexContent>
 *   </complexType>
 * </element>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "text",
    "link",
    "paragraph",
    "word"
})
@XmlRootElement(name = "texts")
public class TextsType {

    protected List<TextType> text;
    protected List<LinkType> link;
    protected List<ParagraphType> paragraph;
    protected List<WordType> word;

    /**
     * Gets the value of the text property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the text property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getText().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TextType }
     * 
     * 
     * @return
     *     The value of the text property.
     */
    public List<TextType> getText() {
        if (text == null) {
            text = new ArrayList<>();
        }
        return this.text;
    }

    public boolean isSetText() {
        return ((this.text!= null)&&(!this.text.isEmpty()));
    }

    public void unsetText() {
        this.text = null;
    }

    /**
     * Gets the value of the link property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the link property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getLink().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link LinkType }
     * 
     * 
     * @return
     *     The value of the link property.
     */
    public List<LinkType> getLink() {
        if (link == null) {
            link = new ArrayList<>();
        }
        return this.link;
    }

    public boolean isSetLink() {
        return ((this.link!= null)&&(!this.link.isEmpty()));
    }

    public void unsetLink() {
        this.link = null;
    }

    /**
     * Gets the value of the paragraph property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the paragraph property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getParagraph().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ParagraphType }
     * 
     * 
     * @return
     *     The value of the paragraph property.
     */
    public List<ParagraphType> getParagraph() {
        if (paragraph == null) {
            paragraph = new ArrayList<>();
        }
        return this.paragraph;
    }

    public boolean isSetParagraph() {
        return ((this.paragraph!= null)&&(!this.paragraph.isEmpty()));
    }

    public void unsetParagraph() {
        this.paragraph = null;
    }

    /**
     * Gets the value of the word property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the word property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getWord().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link WordType }
     * 
     * 
     * @return
     *     The value of the word property.
     */
    public List<WordType> getWord() {
        if (word == null) {
            word = new ArrayList<>();
        }
        return this.word;
    }

    public boolean isSetWord() {
        return ((this.word!= null)&&(!this.word.isEmpty()));
    }

    public void unsetWord() {
        this.word = null;
    }

}
